@@ -295,6 +295,7 @@ def command_module(mod, command, options, ending="_command", cli_options=None):
 
         if (len(tb.splitlines()) == 4):
             print "Modargs Argument Error: %s" % e.message
+            sys.exit(1)
         else:
             # This TypeError comes from within the application, modargs shouldn't catch it.
             print tb
@@ -434,6 +435,9 @@ def help_text(prog, mod, default_command=None, on=False):
         if len(kwargs) > 0:
             text.append(leading_spaces + "Arguments:")
         for k in sorted(kwargs.keys()):
+            if k.startswith("_"):
+                continue
+
             v = kwargs[k]
             doc = kwdocs[k]
             if doc:
@@ -441,6 +445,7 @@ def help_text(prog, mod, default_command=None, on=False):
                 docs = "- %s" % doc
             else:
                 docs = ""
+
             if v is None:
                 arg_help_text = "%s%s %s,\n" % (leading_spaces*2, k, docs)
                 arg_help_text += "%s[required] e.g. '%s --%s <value>'\n" % (leading_spaces*4, prog_on, k)
